/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (icon_red)
#endif
#ifdef __GNUC__
static const guint8 icon_red[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 icon_red[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (4760) */
  "\0\0\22\260"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (140) */
  "\0\0\0\214"
  /* width (35) */
  "\0\0\0#"
  /* height (34) */
  "\0\0\0\""
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0c\0\0\377c\0"
  "\0\377c\0\0\377c\0\0\377c\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0c\0\0\377c\0\0\377c\0\0\377c\0\0"
  "\377\352wz\377\351vx\377\351tw\377\351ru\377\347ps\377c\0\0\377c\0\0"
  "\377c\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0c\0\0\377c\0\0\377c\0\0\377c\0\0\377\357"
  "\206\210\377\357\204\206\377\356\203\205\377\356\201\203\377\355\200"
  "\202\377\354\177\201\377\354}\177\377\353|~\377\352y{\377\351xz\377\351"
  "vx\377\351tw\377c\0\0\377c\0\0\377c\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0c\0\0\377c\0\0\377c\0\0\377c\0\0\377\364\225\227\377\363\222\224\377"
  "\363\220\223\377\363\216\221\377\362\215\217\377\362\213\216\377\361"
  "\212\214\377\361\210\213\377\360\207\211\377\360\205\210\377\357\204"
  "\206\377\357\202\205\377\356\201\203\377\355\200\202\377\354\177\201"
  "\377\354}\177\377\353|~\377\353z|\377\353x{\377c\0\0\377c\0\0\377c\0"
  "\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0c\0\0\377\370\243\247\377\367\242\244\377\367\240\244\377\367\236\242"
  "\377\366\235\237\377\365\234\240\377\365\232\236\377\365\230\232\377"
  "\364\227\231\377\364\225\227\377\364\223\226\377\364\221\224\377\363"
  "\220\223\377\363\216\221\377\362\215\217\377\362\213\216\377\361\212"
  "\214\377\360\211\213\377\360\207\211\377\357\206\210\377\357\204\206"
  "\377\356\203\205\377\356\201\203\377\355\200\202\377\354\177\201\377"
  "\354}\177\377c\0\0\377c\0\0\377c\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0c\0\0\377\351tw\377\347ps\377\371\252\256\377\371\250\254"
  "\377\370\247\253\377\370\245\251\377\367\244\250\377\367\242\244\377"
  "\367\240\244\377\366\237\243\377\366\235\237\377\365\234\240\377\365"
  "\232\236\377\365\230\232\377\364\227\231\377\364\225\227\377\363\222"
  "\224\377\363\220\223\377\363\216\221\377\362\215\217\377\362\213\216"
  "\377\361\212\214\377\361\210\213\377\360\207\211\377\360\205\210\377"
  "\357\204\206\377\357\202\205\377\356\201\203\377\355\200\202\377c\0\0"
  "\377c\0\0\377c\0\0\377\0\0\0\0\0\0\0\0c\0\0\377\355\200\202\377\353|"
  "~\377\351vx\377\347ps\377\372\257\263\377\371\256\261\377\371\254\260"
  "\377\371\252\256\377\371\250\254\377\370\247\253\377\370\245\251\377"
  "\370\243\247\377\367\242\244\377\367\240\244\377\367\236\242\377\366"
  "\235\237\377\365\234\240\377\365\232\236\377\365\230\232\377\364\227"
  "\231\377\364\225\227\377\364\223\226\377\364\221\224\377\363\220\223"
  "\377\363\216\221\377\362\215\217\377\362\213\216\377\361\212\214\377"
  "\360\211\213\377\360\207\211\377\357\206\210\377\357\204\206\377c\0\0"
  "\377\0\0\0\0c\0\0\377\361\212\214\377\360\205\210\377\356\201\203\377"
  "\354}\177\377\351xz\377\351ru\377\372\267\272\377\372\265\270\377\372"
  "\263\266\377\372\261\265\377\372\257\263\377\371\256\261\377\371\254"
  "\260\377\371\252\256\377\371\250\254\377\370\247\253\377\370\245\251"
  "\377\367\244\250\377\367\242\244\377\367\240\244\377\366\237\243\377"
  "\366\235\237\377\365\234\240\377\365\232\236\377\365\230\232\377\364"
  "\227\231\377\364\225\227\377\363\222\224\377\363\220\223\377\351ru\377"
  "\347ps\377\353z|\377c\0\0\377\0\0\0\0c\0\0\377\364\227\231\377\363\222"
  "\224\377\362\213\216\377\360\207\211\377\356\203\205\377\354\177\201"
  "\377\352y{\377\351tw\377\373\276\301\377\373\274\277\377\373\272\275"
  "\377\372\271\274\377\372\267\272\377\372\265\270\377\372\263\266\377"
  "\372\257\263\377\371\256\261\377\371\254\260\377\371\252\256\377\371"
  "\250\254\377\370\247\253\377\370\245\251\377\370\243\247\377\367\242"
  "\244\377\367\240\244\377\367\236\242\377\347ps\377\347ps\377\353z}\377"
  "\371\252\256\377\374\305\310\377\375\314\317\377c\0\0\377\0\0\0\0c\0"
  "\0\377\333$$\377\333$$\377\365\232\236\377\364\223\226\377\363\216\221"
  "\377\361\210\213\377\357\204\206\377\355\200\202\377\353|~\377\351vx"
  "\377\374\303\306\377\374\301\304\377\374\277\302\377\373\276\301\377"
  "\373\274\277\377\373\272\275\377\372\271\274\377\372\267\272\377\372"
  "\265\270\377\372\263\266\377\372\261\265\377\372\257\263\377\371\256"
  "\261\377\347ps\377\347ps\377\353z}\377\364\227\231\377\371\256\261\377"
  "\372\265\270\377\373\274\277\377\374\303\306\377\375\312\315\377c\0\0"
  "\377\0\0\0\0c\0\0\377\372\261\265\377\371\252\256\377\333$$\377\333$"
  "$\377\365\234\240\377\364\225\227\377\363\220\223\377\361\212\214\377"
  "\360\205\210\377\356\201\203\377\354}\177\377\351xz\377\375\312\315\377"
  "\375\310\313\377\374\307\311\377\374\305\310\377\374\303\306\377\374"
  "\301\304\377\373\300\303\377\373\276\301\377\347ps\377\347ps\377\351"
  "xz\377\361\212\214\377\365\230\232\377\366\237\243\377\370\243\247\377"
  "\371\252\256\377\372\263\266\377\373\272\275\377\374\301\304\377\374"
  "\307\311\377c\0\0\377\0\0\0\0c\0\0\377\373\300\303\377\373\272\275\377"
  "\372\263\266\377\372\255\261\377\333$$\377\333$$\377\366\235\237\377"
  "\364\227\231\377\363\222\224\377\362\213\216\377\360\207\211\377\356"
  "\203\205\377\354\177\201\377\352y{\377\375\322\324\377\375\316\321\377"
  "\375\314\317\377\347ps\377\347ps\377\347ps\377\351tw\377\355\200\202"
  "\377\360\207\211\377\362\213\216\377\364\225\227\377\365\234\240\377"
  "\367\242\244\377\371\250\254\377\372\257\263\377\372\271\274\377\373"
  "\300\303\377\372\267\272\377c\0\0\377\0\0\0\0\0\0\0\0c\0\0\377c\0\0\377"
  "\374\301\304\377\373\274\277\377\372\265\270\377\372\257\263\377\333"
  "$$\377\333$$\377\366\237\243\377\365\232\236\377\364\223\226\377\363"
  "\216\221\377\361\210\213\377\357\204\206\377\355\200\202\377\347ps\377"
  "\346oq\377\346oq\377\346oq\377\351tw\377\353|~\377\356\201\203\377\360"
  "\207\211\377\362\215\217\377\364\223\226\377\365\232\236\377\367\240"
  "\244\377\370\247\253\377\371\256\261\377\372\265\270\377\373\276\301"
  "\377\367\236\240\377c\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0c\0\0\377"
  "c\0\0\377\374\303\306\377\373\276\301\377\372\267\272\377\372\261\265"
  "\377\333$$\377\333$$\377\367\240\244\377\365\234\240\377\364\225\227"
  "\377\363\220\223\377\361\212\214\377\347ps\377\330##\377\336]`\377\345"
  "hk\377\347nq\377\352y{\377\355\200\202\377\357\204\206\377\361\212\214"
  "\377\364\221\224\377\365\230\232\377\366\237\243\377\370\245\251\377"
  "\371\254\260\377\372\265\270\377\371\246\252\377\352qt\377_\0\0\377\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0c\0\0\377c\0\0\377\374"
  "\305\310\377\373\300\303\377\373\272\275\377\372\263\266\377\333$$\377"
  "\333$$\377\367\242\244\377\366\235\237\377\364\227\231\377\347ps\377"
  "\313\16\22\377\325FF\377\336]`\377\342eh\377\350qt\377\354}\177\377\357"
  "\202\205\377\361\210\213\377\363\216\221\377\364\227\231\377\366\237"
  "\243\377\364\225\227\377\357~\201\377c\0\0\377c\0\0\377g\0\0\377\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "c\0\0\377c\0\0\377\374\307\311\377\374\301\304\377\373\274\277\377\372"
  "\265\270\377\333$$\377\333$$\377\370\243\247\377\347ps\377\310\11\16"
  "\377\325\34\34\377\327::\377\331RU\377\342cf\377\351tw\377\355~\200\377"
  "\361\210\213\377\356\177\202\377\345jm\377c\0\0\377c\0\0\377c\0\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0c\0\0\377c\0\0\377\375\310"
  "\313\377\374\303\306\377\373\276\301\377\372\267\272\377\372\261\265"
  "\377\347ps\377\310\11\16\377\311\14\20\377\312\15\21\377\326\37#\377"
  "\325<@\377\332WZ\377\345hk\377c\0\0\377c\0\0\377c\0\0\377\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0c\0\0\377c\0\0\377\375\312\315\377\374\305\310\377\373\300\303\377"
  "\347ps\377\322\27\33\377\332''\377\326KK\377\330\35\35\377c\0\0\377c"
  "\0\0\377_\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0c\0\0\377c\0\0\377\375\314\317\377\347ps\377\325JJ\377c\0\0\377c"
  "\0\0\377_\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0c\0\0\377c\0\0\377c\0\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (icon_green)
#endif
#ifdef __GNUC__
static const guint8 icon_green[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 icon_green[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (4760) */
  "\0\0\22\260"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (140) */
  "\0\0\0\214"
  /* width (35) */
  "\0\0\0#"
  /* height (34) */
  "\0\0\0\""
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0$\77$\377$\77"
  "$\377$\77$\377$\77$\377$\77$\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0$\77$\377$\77$\377$\77$\377$\77$"
  "\377\212\327\225\377\210\327\223\377\207\326\222\377\205\326\217\377"
  "\202\325\216\377$\77$\377$\77$\377$\77$\377\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0$\77$\377$"
  "\77$\377$\77$\377$\77$\377\226\337\240\377\224\337\237\377\223\336\236"
  "\377\221\336\234\377\220\335\233\377\220\333\232\377\216\333\231\377"
  "\215\332\230\377\211\332\225\377\210\331\224\377\210\327\223\377\206"
  "\327\221\377$\77$\377$\77$\377$\77$\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0$\77"
  "$\377$\77$\377$\77$\377$\77$\377\243\346\253\377\241\344\252\377\237"
  "\344\250\377\236\343\250\377\234\343\246\377\233\342\245\377\232\341"
  "\244\377\231\340\243\377\227\340\237\377\226\337\237\377\224\337\235"
  "\377\223\336\234\377\221\336\234\377\220\335\233\377\220\333\232\377"
  "\216\333\231\377\215\332\230\377\213\332\226\377\213\330\226\377$\77"
  "$\377$\77$\377$\77$\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0$\77$\377\260\353\267\377\257\352\266\377\255\352\264"
  "\377\255\350\264\377\253\350\262\377\250\351\260\377\250\347\257\377"
  "\246\347\255\377\245\346\255\377\243\346\253\377\242\345\252\377\241"
  "\344\251\377\237\344\250\377\236\343\250\377\234\343\246\377\233\342"
  "\245\377\231\342\243\377\230\341\242\377\226\341\241\377\226\337\240"
  "\377\224\337\237\377\223\336\236\377\221\336\234\377\220\335\233\377"
  "\220\333\232\377\216\333\231\377$\77$\377$\77$\377$\77$\377\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0$\77$\377\206\327\221\377\202\325\216\377"
  "\266\355\275\377\264\355\273\377\262\355\272\377\261\354\272\377\260"
  "\353\270\377\257\352\267\377\255\352\266\377\254\351\265\377\252\351"
  "\263\377\250\351\260\377\250\347\257\377\246\347\255\377\245\346\255"
  "\377\243\346\253\377\241\344\252\377\237\344\250\377\236\343\250\377"
  "\234\343\246\377\233\342\245\377\232\341\244\377\231\340\243\377\227"
  "\340\237\377\226\337\237\377\224\337\235\377\223\336\234\377\221\336"
  "\234\377\220\335\233\377$\77$\377$\77$\377$\77$\377\0\0\0\0\0\0\0\0$"
  "\77$\377\220\335\233\377\215\332\230\377\210\327\223\377\202\325\216"
  "\377\273\356\302\377\271\356\300\377\267\356\275\377\266\355\275\377"
  "\264\355\273\377\262\355\271\377\262\353\270\377\260\353\267\377\257"
  "\352\266\377\255\352\264\377\255\350\264\377\253\350\262\377\250\351"
  "\260\377\250\347\257\377\246\347\255\377\245\346\255\377\243\346\253"
  "\377\242\345\252\377\241\344\251\377\237\344\250\377\236\343\250\377"
  "\234\343\246\377\233\342\245\377\231\342\243\377\230\341\242\377\226"
  "\341\241\377\226\337\240\377\224\337\237\377$\77$\377\0\0\0\0$\77$\377"
  "\232\341\244\377\226\337\237\377\221\336\234\377\216\333\231\377\210"
  "\331\224\377\205\326\221\377\301\360\306\377\277\360\305\377\275\360"
  "\304\377\273\360\303\377\273\356\302\377\271\356\300\377\267\356\275"
  "\377\266\355\275\377\264\355\273\377\262\355\272\377\261\354\272\377"
  "\260\353\270\377\257\352\267\377\255\352\266\377\254\351\265\377\252"
  "\351\263\377\250\351\260\377\250\347\257\377\246\347\255\377\245\346"
  "\255\377\243\346\253\377\241\344\252\377\237\344\250\377\205\326\221"
  "\377\202\325\216\377\213\332\226\377$\77$\377\0\0\0\0$\77$\377\244\347"
  "\255\377\241\344\252\377\233\342\245\377\227\340\237\377\223\336\236"
  "\377\220\333\232\377\211\332\225\377\206\327\221\377\306\363\313\377"
  "\306\361\313\377\304\361\311\377\302\361\307\377\301\360\306\377\277"
  "\360\305\377\275\360\303\377\273\356\302\377\271\356\300\377\267\356"
  "\275\377\266\355\275\377\264\355\273\377\262\355\271\377\262\353\270"
  "\377\260\353\267\377\257\352\266\377\255\352\264\377\255\350\264\377"
  "\202\325\216\377\202\325\216\377\213\332\226\377\266\355\273\377\315"
  "\364\321\377\323\366\327\377$\77$\377\0\0\0\0$\77$\377Y\246Y\377Y\246"
  "Y\377\250\347\257\377\241\346\253\377\236\343\246\377\231\340\243\377"
  "\224\337\235\377\220\335\233\377\215\332\230\377\210\327\223\377\313"
  "\364\317\377\312\363\316\377\310\363\314\377\306\363\313\377\306\361"
  "\312\377\304\361\311\377\302\361\307\377\301\360\306\377\277\360\305"
  "\377\275\360\304\377\273\360\303\377\273\356\302\377\271\356\300\377"
  "\202\325\216\377\202\325\216\377\213\332\226\377\244\347\257\377\271"
  "\356\300\377\277\360\305\377\306\361\313\377\313\364\317\377\321\366"
  "\326\377$\77$\377\0\0\0\0$\77$\377\275\356\302\377\266\355\275\377Y\246"
  "Y\377Y\246Y\377\250\351\260\377\243\346\255\377\240\343\250\377\232\341"
  "\244\377\226\337\237\377\221\336\234\377\216\333\231\377\210\331\224"
  "\377\321\366\326\377\321\364\325\377\317\364\323\377\315\365\322\377"
  "\313\364\320\377\312\363\320\377\310\363\316\377\306\363\313\377\202"
  "\325\216\377\202\325\216\377\210\331\224\377\232\341\244\377\246\347"
  "\255\377\254\351\265\377\260\353\267\377\266\355\275\377\275\360\303"
  "\377\304\361\311\377\312\363\320\377\317\364\323\377$\77$\377\0\0\0\0"
  "$\77$\377\310\363\316\377\304\361\311\377\275\360\303\377\271\356\276"
  "\377Y\246Y\377Y\246Y\377\252\351\263\377\244\347\255\377\241\344\252"
  "\377\233\342\245\377\227\340\237\377\223\336\236\377\220\333\232\377"
  "\211\332\225\377\331\366\334\377\325\366\332\377\323\366\327\377\202"
  "\325\216\377\202\325\216\377\202\325\216\377\206\327\221\377\220\335"
  "\233\377\227\340\237\377\233\342\245\377\243\346\255\377\250\351\260"
  "\377\257\352\266\377\264\355\273\377\273\356\302\377\302\361\307\377"
  "\310\363\316\377\301\360\306\377$\77$\377\0\0\0\0\0\0\0\0$\77$\377$\77"
  "$\377\312\363\320\377\306\361\313\377\277\360\306\377\273\356\301\377"
  "Y\246Y\377Y\246Y\377\254\351\265\377\250\347\257\377\241\346\253\377"
  "\236\343\246\377\231\340\243\377\224\337\235\377\220\335\233\377\202"
  "\325\216\377\201\324\214\377\201\324\214\377\201\324\214\377\206\327"
  "\221\377\215\332\230\377\221\336\234\377\226\341\241\377\234\343\246"
  "\377\242\345\252\377\250\347\257\377\255\352\266\377\262\355\271\377"
  "\271\356\300\377\277\360\306\377\306\363\313\377\255\350\261\377$\77"
  "$\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0$\77$\377$\77$\377\313\364\320\377"
  "\306\363\313\377\300\361\307\377\275\356\302\377Y\246Y\377Y\246Y\377"
  "\255\352\266\377\250\351\260\377\243\346\255\377\240\343\250\377\232"
  "\341\244\377\202\325\216\377U\246Y\377t\307|\377}\320\207\377\202\323"
  "\215\377\211\332\225\377\220\335\233\377\224\337\235\377\232\341\244"
  "\377\241\344\251\377\246\347\255\377\254\351\265\377\261\354\272\377"
  "\267\356\275\377\277\360\306\377\264\353\270\377\210\323\214\377#<#\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0$\77$\377$\77$\377\315"
  "\364\321\377\310\363\316\377\304\361\311\377\275\360\303\377Y\246Y\377"
  "Y\246Y\377\257\352\266\377\252\351\263\377\244\347\255\377\202\325\216"
  "\377Q\210S\377f\265f\377t\307|\377y\316\203\377\203\326\217\377\216\333"
  "\231\377\223\336\234\377\231\340\243\377\236\343\250\377\245\346\255"
  "\377\254\351\265\377\244\345\252\377\223\332\226\377$\77$\377$\77$\377"
  "%B%\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0$\77$\377$\77$\377\317\364\323\377\312\363\320\377\306\361"
  "\313\377\277\360\306\377Y\246Y\377Y\246Y\377\260\353\267\377\202\325"
  "\216\377O\202Q\377V\233V\377b\257b\377n\275q\377z\313\203\377\207\326"
  "\222\377\220\333\231\377\231\340\243\377\221\334\232\377\200\317\207"
  "\377$\77$\377$\77$\377$\77$\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0$\77$\377$\77$\377\321\364\325\377\313\364\320\377\306\363\313"
  "\377\300\361\307\377\275\356\302\377\202\325\216\377O\202Q\377P\205R"
  "\377P\207S\377V\237Z\377_\262e\377o\302w\377~\317\207\377$\77$\377$\77"
  "$\377$\77$\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0$\77$\377$\77$\377\321\366\326\377\315"
  "\364\321\377\310\363\316\377\202\325\216\377S\226W\377Y\250Y\377j\267"
  "j\377W\236W\377$\77$\377$\77$\377#<#\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0$\77$\377$\77$\377\323\366\327\377\202\325"
  "\216\377h\267h\377$\77$\377$\77$\377#<#\377\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0$\77$\377$\77$\377$\77$\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (icon_yellow)
#endif
#ifdef __GNUC__
static const guint8 icon_yellow[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 icon_yellow[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (4760) */
  "\0\0\22\260"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (140) */
  "\0\0\0\214"
  /* width (35) */
  "\0\0\0#"
  /* height (34) */
  "\0\0\0\""
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0cT\0\377cT\0"
  "\377cT\0\377cT\0\377cT\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0cT\0\377cT\0\377cT\0\377cT\0\377\351"
  "\335x\377\351\335v\377\351\334t\377\350\334s\377\346\332q\377cT\0\377"
  "cT\0\377cT\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0cT\0\377cT\0\377cT\0\377cT\0\377\357"
  "\344\206\377\357\344\204\377\356\343\203\377\356\342\201\377\355\341"
  "\200\377\354\341\177\377\354\340}\377\353\340|\377\352\336y\377\351\335"
  "x\377\351\335v\377\350\334u\377cT\0\377cT\0\377cT\0\377\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0cT\0\377cT\0\377cT\0\377cT\0\377\364\352\225\377\363\351"
  "\222\377\363\350\220\377\362\350\217\377\362\347\215\377\361\347\214"
  "\377\361\346\212\377\361\343\210\377\360\345\207\377\360\344\205\377"
  "\357\344\204\377\357\343\202\377\356\342\201\377\355\341\200\377\354"
  "\341\177\377\354\340}\377\353\340|\377\353\337z\377\352\336y\377cT\0"
  "\377cT\0\377cT\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0cT\0\377\370\357\243\377\367\356\242\377\367\356\240"
  "\377\367\353\236\377\366\355\235\377\365\354\234\377\365\354\232\377"
  "\365\353\230\377\364\353\227\377\364\352\225\377\363\351\224\377\363"
  "\347\222\377\363\350\220\377\362\350\217\377\362\347\215\377\361\347"
  "\214\377\361\346\212\377\360\345\211\377\360\345\207\377\357\344\206"
  "\377\357\344\204\377\356\343\203\377\356\342\201\377\355\341\200\377"
  "\354\341\177\377\354\340}\377cT\0\377cT\0\377cT\0\377\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0cT\0\377\350\334u\377\346\332q\377\370\360\252"
  "\377\371\360\250\377\370\357\247\377\370\357\245\377\367\356\244\377"
  "\367\356\242\377\367\356\240\377\366\355\237\377\366\355\235\377\365"
  "\354\234\377\365\354\232\377\365\353\230\377\364\353\227\377\364\352"
  "\225\377\363\351\222\377\363\350\220\377\362\350\217\377\362\347\215"
  "\377\361\347\214\377\361\346\212\377\361\343\210\377\360\345\207\377"
  "\360\344\205\377\357\344\204\377\357\343\202\377\356\342\201\377\355"
  "\341\200\377cT\0\377cT\0\377cT\0\377\0\0\0\0\0\0\0\0cT\0\377\355\341"
  "\200\377\353\340|\377\351\335v\377\346\332q\377\371\362\260\377\371\361"
  "\256\377\371\361\254\377\370\360\252\377\371\360\250\377\370\357\247"
  "\377\370\357\245\377\370\357\243\377\367\356\242\377\367\356\240\377"
  "\367\353\236\377\366\355\235\377\365\354\234\377\365\354\232\377\365"
  "\353\230\377\364\353\227\377\364\352\225\377\363\351\224\377\363\347"
  "\222\377\363\350\220\377\362\350\217\377\362\347\215\377\361\347\214"
  "\377\361\346\212\377\360\345\211\377\360\345\207\377\357\344\206\377"
  "\357\344\204\377cT\0\377\0\0\0\0cT\0\377\361\346\212\377\360\344\205"
  "\377\356\342\201\377\354\340}\377\351\335x\377\350\334s\377\372\363\267"
  "\377\372\363\265\377\372\363\263\377\372\362\261\377\371\362\260\377"
  "\371\361\256\377\371\361\254\377\370\360\252\377\371\360\250\377\370"
  "\357\247\377\370\357\245\377\367\356\244\377\367\356\242\377\367\356"
  "\240\377\366\355\237\377\366\355\235\377\365\354\234\377\365\354\232"
  "\377\365\353\230\377\364\353\227\377\364\352\225\377\363\351\222\377"
  "\363\350\220\377\350\334s\377\346\332q\377\353\337z\377cT\0\377\0\0\0"
  "\0cT\0\377\364\352\227\377\363\351\222\377\361\347\214\377\360\345\207"
  "\377\356\343\203\377\354\341\177\377\352\336y\377\350\334u\377\373\365"
  "\276\377\373\364\274\377\373\364\272\377\372\363\271\377\372\363\267"
  "\377\372\363\265\377\372\363\263\377\371\362\260\377\371\361\256\377"
  "\371\361\254\377\370\360\252\377\371\360\250\377\370\357\247\377\370"
  "\357\245\377\370\357\243\377\367\356\242\377\367\356\240\377\367\353"
  "\236\377\346\332q\377\346\332q\377\353\337z\377\371\360\252\377\374\366"
  "\305\377\375\371\314\377cT\0\377\0\0\0\0cT\0\377\333\303$\377\333\303"
  "$\377\365\354\232\377\363\351\224\377\363\346\216\377\361\343\210\377"
  "\357\344\204\377\355\341\200\377\353\340|\377\351\335v\377\374\366\303"
  "\377\374\366\301\377\374\365\277\377\373\365\276\377\373\364\274\377"
  "\373\364\272\377\372\363\271\377\372\363\267\377\372\363\265\377\372"
  "\363\263\377\372\362\261\377\371\362\260\377\371\361\256\377\346\332"
  "q\377\346\332q\377\353\337z\377\364\352\227\377\371\361\256\377\372\363"
  "\265\377\373\364\274\377\374\366\303\377\374\367\313\377cT\0\377\0\0"
  "\0\0cT\0\377\372\362\261\377\370\360\252\377\333\303$\377\333\303$\377"
  "\365\354\234\377\364\352\225\377\363\350\220\377\361\346\212\377\360"
  "\344\205\377\356\342\201\377\354\340}\377\351\335x\377\374\367\313\377"
  "\375\367\310\377\374\366\307\377\374\366\305\377\374\366\303\377\374"
  "\366\301\377\373\365\300\377\373\365\276\377\346\332q\377\346\332q\377"
  "\351\335x\377\361\346\212\377\365\353\230\377\366\355\237\377\370\357"
  "\243\377\370\360\252\377\372\363\263\377\373\364\272\377\374\366\301"
  "\377\374\366\307\377cT\0\377\0\0\0\0cT\0\377\373\365\300\377\373\364"
  "\272\377\372\363\263\377\371\361\256\377\333\303$\377\333\303$\377\366"
  "\355\235\377\364\352\227\377\363\351\222\377\361\347\214\377\360\345"
  "\207\377\356\343\203\377\354\341\177\377\352\336y\377\375\371\322\377"
  "\375\371\316\377\375\371\314\377\346\332q\377\346\332q\377\346\332q\377"
  "\350\334u\377\355\341\200\377\360\345\207\377\361\347\214\377\364\352"
  "\225\377\365\354\234\377\367\356\242\377\371\360\250\377\371\362\260"
  "\377\372\363\271\377\373\365\300\377\372\363\267\377cT\0\377\0\0\0\0"
  "\0\0\0\0cT\0\377cT\0\377\374\366\301\377\373\364\274\377\372\363\265"
  "\377\371\362\260\377\333\303$\377\333\303$\377\366\355\237\377\365\354"
  "\232\377\363\351\224\377\363\346\216\377\361\343\210\377\357\344\204"
  "\377\355\341\200\377\346\332q\377\346\331o\377\346\331o\377\346\331o"
  "\377\350\334u\377\353\340|\377\356\342\201\377\360\345\207\377\362\347"
  "\215\377\363\351\224\377\365\354\232\377\367\356\240\377\370\357\247"
  "\377\371\361\256\377\372\363\265\377\373\365\276\377\367\356\236\377"
  "cT\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0cT\0\377cT\0\377\374\366\303"
  "\377\373\365\276\377\372\363\267\377\372\362\261\377\333\303$\377\333"
  "\303$\377\367\356\240\377\365\354\234\377\364\352\225\377\363\350\220"
  "\377\361\346\212\377\346\332q\377\330\301#\377\336\315]\377\344\327i"
  "\377\346\331o\377\352\336y\377\355\341\200\377\357\344\204\377\361\346"
  "\212\377\363\347\222\377\365\353\230\377\366\355\237\377\370\357\245"
  "\377\371\361\254\377\372\363\265\377\371\356\246\377\351\332r\377_Q\0"
  "\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0cT\0\377cT\0\377"
  "\374\366\305\377\373\365\300\377\373\364\272\377\372\363\263\377\333"
  "\303$\377\333\303$\377\367\356\242\377\366\355\235\377\364\352\227\377"
  "\346\332q\377\312\262\17\377\325\277F\377\336\315]\377\342\324e\377\347"
  "\333r\377\354\340}\377\357\343\202\377\361\343\210\377\362\350\217\377"
  "\364\353\227\377\366\355\237\377\364\352\225\377\357\340~\377cT\0\377"
  "cT\0\377gX\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0cT\0\377cT\0\377\374\366\307\377\374\366\301\377"
  "\373\364\274\377\372\363\265\377\333\303$\377\333\303$\377\370\357\243"
  "\377\346\332q\377\306\256\13\377\325\275\34\377\327\277:\377\331\310"
  "R\377\342\321c\377\351\334t\377\355\341~\377\361\343\210\377\356\340"
  "\177\377\345\325j\377cT\0\377cT\0\377cT\0\377\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0cT\0\377cT\0\377\375\367\310\377\374\366\303\377"
  "\373\365\276\377\372\363\267\377\372\362\261\377\346\332q\377\306\256"
  "\13\377\310\260\15\377\311\261\16\377\325\276\40\377\324\300=\377\332"
  "\311W\377\344\324i\377cT\0\377cT\0\377cT\0\377\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0cT\0\377"
  "cT\0\377\374\367\313\377\374\366\305\377\373\365\300\377\346\332q\377"
  "\320\270\31\377\332\303'\377\326\301K\377\330\277\35\377cT\0\377cT\0"
  "\377_Q\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "cT\0\377cT\0\377\375\371\314\377\346\332q\377\325\303J\377cT\0\377cT"
  "\0\377_Q\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0cT\0\377cT\0\377cT\0\377\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (icon_unknown)
#endif
#ifdef __GNUC__
static const guint8 icon_unknown[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 icon_unknown[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (4760) */
  "\0\0\22\260"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (140) */
  "\0\0\0\214"
  /* width (35) */
  "\0\0\0#"
  /* height (34) */
  "\0\0\0\""
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0"
  "\0\0\377|\252\321\377S\226\312\377S\226\312\3771|\274\3771|\274\3779"
  "o\234\3779o\234\3776\\y\3776\\y\377\20""1M\377\0\2\3\377\0\0\0\377\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377|\252\321\377S\226\312\3772v\257\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\33A^\377"
  "6\\y\377+g\226\377\35Nt\377\20""1M\377\0\2\3\377\0\0\0\377\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\3\377|\252\321"
  "\377S\226\312\377$Jg\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\2\3\377!Pt\377.e\217\377+g\226\377"
  ":c\205\377\20""1M\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\377|\252\321\377K\210\274\3774Yy\377\0\0\0\377\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\2\3\377@x\247\377-v\256\377+g\226\377\35Nt\377\0\2\3\377\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\3\377|\252\321\3772v\257\377"
  "\34Ik\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377M\221\312\3771|\274\377-v\256"
  "\377&`\221\377\20""1M\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377|\252\321\377S\226\312\377\40Ow\377\0\2\3\377\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\2\3\377S\226\312\377-v\256\377(g\227\377\30Gk\377\0\0\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377S\226\312\3771|\274\377\33Gl\377"
  "\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377p\246\317\3771|\274\377"
  "%e\226\377\27Fj\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377S\226"
  "\312\377-v\256\377\35Nx\377\0\2\3\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2"
  "\3\377|\252\321\3771|\274\377-v\256\377\27Fj\377\0\0\0\377\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\3772v\257\3771|\274\377)b\222\3778b\203\377"
  "\0\2\3\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377|\252\321\377S\226\312\3771|\274"
  "\377-v\256\377\20""1M\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\3772v\257\377#a\220\377&k\241\3772v\257\377K\210\274\377S\226\312\377"
  "S\226\312\377\0\2\3\377\0\0\0\377111\377111\377\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\2\3\377|\252\321\3771|\274\377-v\256\377\40Ow\377\0\2\3"
  "\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\3\377\32Iq\377#"
  "a\220\377-v\256\377-v\256\3771|\274\3771|\274\3772v\257\377\0\0\0\377"
  "\277\260\232\377\274\256\231\377111\377111\377111\377\0\2\3\377|\252"
  "\321\377S\226\312\3771|\274\377+e\222\377\20""1M\377\0\0\0\377\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0""111\377111\377111\377\0\2\3\377\20""1M\377\33"
  "Lv\377%a\220\377-v\256\377-v\256\377\27Eh\377\0\0\0\377\302\270\243\377"
  "\301\266\240\377\277\265\240\377\277\264\236\377\0\2\3\377\222\263\317"
  "\377R\235\327\3771|\274\377)b\222\377\20""1M\377\0\2\3\377\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""111\377"
  "111\377111\377111\377\323\310\264\377\321\306\262\377\321\305\260\377"
  "\320\303\257\377\0\0\0\377\0\2\3\377\20""1M\377\27Fj\377\20""1M\377\0"
  "\2\3\377\311\276\250\377\311\273\246\377\307\274\246\377\306\273\245"
  "\377\0\2\3\377\205\257\320\377R\235\327\377/\206\320\377(d\223\377\20"
  "1M\377\0\2\3\377111\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0""111\377\334\317\275\377\332\320\275\377\332\317\273"
  "\377\332\315\271\377\330\315\271\377\326\315\271\377\325\312\270\377"
  "\326\313\265\377\323\313\266\377\323\310\264\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\320\303\257\377\317\303\256\377\316\302\255\377\315\302\254"
  "\377\0\2\3\377\222\263\317\377R\235\327\377/\206\320\377(d\223\377\20"
  "1M\377\0\2\3\377\304\272\245\377\304\271\243\377111\377111\377111\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""111\377\277\261\234\377\274"
  "\256\231\377\337\324\302\377\337\322\300\377\335\323\300\377\335\321"
  "\276\377\332\322\277\377\332\320\275\377\332\317\273\377\330\317\273"
  "\377\330\315\271\377\326\315\271\377\325\312\270\377\326\313\265\377"
  "\323\313\266\377\323\310\264\377\0\2\3\377\205\257\320\377R\232\327\377"
  "/\206\320\377(d\223\377\20""1M\377\0\2\3\377\313\300\252\377\313\275"
  "\250\377\311\276\250\377\311\273\246\377\307\274\246\377\306\273\245"
  "\377111\377111\377111\377\0\0\0\0\0\0\0\0""111\377\306\273\245\377\302"
  "\270\243\377\277\264\236\377\274\256\231\377\342\327\305\377\340\327"
  "\305\377\340\325\303\377\337\324\302\377\337\322\300\377\335\323\300"
  "\377\335\321\276\377\334\317\275\377\332\320\275\377\332\317\273\377"
  "\332\315\271\377\0\2\3\377\222\263\317\377R\232\327\377/\206\320\377"
  ")b\222\377\20""1M\377\0\2\3\377\322\305\261\377\321\305\260\377\320\303"
  "\257\377\317\303\256\377\316\302\255\377\315\302\254\377\314\301\253"
  "\377\313\300\252\377\311\277\252\377\311\276\250\377111\377\0\0\0\0""1"
  "11\377\315\302\254\377\313\275\250\377\307\274\246\377\304\271\243\377"
  "\277\265\240\377\277\260\232\377\343\334\314\377\343\334\312\377\343"
  "\332\310\377\342\330\307\377\342\327\305\377\340\327\305\377\340\325"
  "\303\377\337\324\302\377\0\0\0\377\222\263\317\377|\252\321\3775\212"
  "\322\377-v\256\377\36Qy\377\0\2\3\377\330\315\271\377\326\315\271\377"
  "\325\312\270\377\326\313\265\377\323\313\266\377\323\310\264\377\321"
  "\306\262\377\321\305\260\377\277\260\232\377\274\256\231\377\302\267"
  "\241\377111\377\0\0\0\0""111\377\323\313\266\377\321\306\262\377\316"
  "\302\255\377\313\300\252\377\307\275\250\377\304\272\245\377\301\266"
  "\240\377\277\261\234\377\346\341\321\377\346\337\317\377\346\336\315"
  "\377\343\336\316\377\343\334\314\377\343\334\312\377\0\2\3\377|\252\321"
  "\377R\232\327\377<x\253\377+e\222\377\20""1M\377\0\0\0\377\335\321\276"
  "\377\334\317\275\377\332\320\275\377\332\317\273\377\332\315\271\377"
  "\274\256\231\377\274\256\231\377\302\266\241\377\337\324\302\377\352"
  "\344\325\377\356\347\331\377111\377\0\0\0\0""111\377\312I3\377\312I3"
  "\377\325\312\270\377\323\307\262\377\320\303\257\377\314\300\253\377"
  "\311\276\250\377\306\273\245\377\302\270\243\377\277\264\236\377\352"
  "\342\323\377\352\341\321\377\351\337\320\377\0\0\0\377\222\263\317\377"
  "p\246\317\377G\230\326\377-v\256\377\33Lv\377\0\2\3\377\342\330\307\377"
  "\342\327\305\377\340\327\305\377\274\256\231\377\274\256\231\377\302"
  "\266\241\377\323\313\266\377\340\327\305\377\343\334\312\377\346\337"
  "\317\377\352\342\323\377\356\345\327\377111\377\0\0\0\0""111\377\342"
  "\330\307\377\337\324\302\377\312I3\377\312I3\377\326\315\271\377\323"
  "\310\264\377\321\305\260\377\315\302\254\377\313\275\250\377\307\274"
  "\246\377\304\271\243\377\277\265\240\377\356\345\327\377\0\0\0\377p\246"
  "\317\377@\220\315\377-v\256\377(g\227\377\27Eh\377\0\0\0\377\274\256"
  "\231\377\274\256\231\377\277\265\240\377\315\302\254\377\326\313\265"
  "\377\330\317\273\377\334\317\275\377\337\324\302\377\343\332\310\377"
  "\346\336\315\377\352\341\321\377\352\345\327\377111\377\0\0\0\0""111"
  "\377\347\341\322\377\346\336\315\377\343\332\310\377\342\325\303\377"
  "\312I3\377\312I3\377\330\315\271\377\323\313\266\377\321\306\262\377"
  "\316\302\255\377\313\300\252\377\307\275\250\377\304\272\245\377\0\0"
  "\0\377@\220\315\377-v\256\377(g\227\377\27Eh\377\20""1M\377\0\0\0\377"
  "\277\261\234\377\306\273\245\377\313\300\252\377\316\302\255\377\323"
  "\310\264\377\326\315\271\377\332\320\275\377\337\322\300\377\342\327"
  "\305\377\343\336\316\377\347\341\322\377\343\334\314\377111\377\0\0\0"
  "\0\0\0\0\0""111\377111\377\352\341\321\377\346\337\317\377\343\334\312"
  "\377\342\327\305\377\312I3\377\312I3\377\330\317\273\377\325\312\270"
  "\377\323\307\262\377\320\303\257\377\314\300\253\377\311\276\250\377"
  "\0\2\3\377\20""1M\377\27Eh\377\20""1M\377\0\2\3\377\277\261\234\377\302"
  "\270\243\377\307\274\246\377\313\300\252\377\317\303\256\377\323\307"
  "\262\377\325\312\270\377\332\317\273\377\335\323\300\377\340\327\305"
  "\377\343\334\312\377\346\341\321\377\332\315\271\377111\377\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0""111\377111\377\352\342\323\377\346\341\321\377"
  "\343\334\314\377\342\330\307\377\312I3\377\312I3\377\332\317\273\377"
  "\326\315\271\377\323\310\264\377\321\305\260\377\315\302\254\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\270\247\223\377\274\254\227\377\301\266\240"
  "\377\306\273\245\377\311\276\250\377\315\302\254\377\322\305\261\377"
  "\326\313\265\377\330\317\273\377\335\321\276\377\340\325\303\377\343"
  "\334\312\377\337\321\276\377\277\256\232\377///\377\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""111\377111\377\352\344\325\377\347\341"
  "\322\377\346\336\315\377\343\332\310\377\312I3\377\312I3\377\332\320"
  "\275\377\330\315\271\377\323\313\266\377\274\256\231\377\273\34\34\377"
  "\260\205i\377\261\235\210\377\265\244\220\377\275\257\232\377\304\271"
  "\243\377\311\273\246\377\314\300\253\377\320\303\257\377\323\313\266"
  "\377\330\317\273\377\323\310\264\377\310\270\243\377111\377111\377f\0"
  "\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0""111\377111\377\352\345\327\377\352\341\321\377\346\337\317"
  "\377\343\334\312\377\312I3\377\312I3\377\334\317\275\377\274\256\231"
  "\377\272\25\31\377\306<)\377\267sX\377\256\223{\377\264\242\217\377\277"
  "\261\234\377\306\271\243\377\314\300\253\377\307\271\244\377\270\251"
  "\225\377111\377111\377111\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0""111\377111\377\356\344\325\377\352\342\323\377\346\341\321\377"
  "\343\334\314\377\342\330\307\377\0\0\0\377\0\0\0\377\0\0\0\377\272\33"
  "\33\377\301@2\377\261u^\377\256\230\201\377\270\247\223\377111\37711"
  "1\377111\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0""111\377111\377\356\345\327\377\352\344"
  "\325\377\0\2\3\3776\211\317\377:`\201\3776[{\377\0\2\3\377\310=+\377"
  "111\377111\377///\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0""111\377\0\0\0\3776\211\317\377|\252\321\377X\235\327\3776\211"
  "\317\377\33Hj\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377(Qs\377Y\235"
  "\326\3776\211\317\377&a\217\377\20""1M\377\0\0\0\377\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\2\3\377\34Ik\377\27Eh\377\20""1M\377\0\2\3\377\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};


